=head1 Name

Test::SPVM::Sys::Socket - Test Utilities for SPVM::Sys::Socket

=head1 Description

Test::SPVM::Sys::Socket module is test utilities for L<SPVM::Sys::Socket>.

=head1 Modules

=over 2

=item * L<SPVM::Sys::Socket::Server>

=item * L<SPVM::Sys::Socket::Util>

=back
